==> ktp-text-ui_22.12.1.orig.tar.xz: ktp-text-ui-22.12.1/filters/otr/ktptextui_message_filter_otr.desktop.cmake <==
[Desktop Entry]
Name=OTR
Name[bs]=OTR
Name[ca]=OTR
Name[ca@valencia]=OTR
Name[cs]=OTR
Name[da]=OTR
Name[de]=OTR
Name[el]=OTR
Name[en_GB]=OTR
Name[es]=OTR
Name[et]=OTR
Name[eu]=OTR
Name[fi]=OTR
Name[fr]=OTR
Name[gl]=OTR
Name[hu]=OTR
Name[ia]=OTR
Name[it]=OTR
Name[ka]=OTR
Name[ko]=OTR
Name[nb]=OTR
Name[nl]=OTR
Name[nn]=OTR
Name[pl]=OTR
Name[pt]=OTR
Name[pt_BR]=OTR
Name[ro]=OTR
Name[ru]=OTR
Name[sk]=OTR
Name[sl]=OTR
Name[sr]=ОТР
Name[sr@ijekavian]=ОТР
Name[sr@ijekavianlatin]=OTR
Name[sr@latin]=OTR
Name[sv]=OTR
Name[tr]=OTR
Name[uk]=OTR
Name[x-test]=xxOTRxx
Name[zh_CN]=非公开加密
Name[zh_TW]=OTR
Comment=If a message is an OTR message, it will not be shown
Comment[bs]=Ako je poruka OTR poruka, ona neće biti prikazana
Comment[ca]=Si un missatge és OTR, no es mostrarà
Comment[ca@valencia]=Si un missatge és OTR, no es mostrarà
Comment[cs]=Pokud je zpráva OTR, nebude zobrazena
Comment[da]=Hvis en besked er en OTR-besked, vil den ikke blive vist
Comment[de]=Wenn eine Nachricht vom Typ OTR ist, wird sie nicht angezeigt
Comment[el]=Αν ένα μήνυμα είναι μήνυμα OTR, δεν θα εμφανιστεί
Comment[en_GB]=If a message is an OTR message, it will not be shown
Comment[es]=Si un mensaje es un mensaje OTR, no se mostrará
Comment[et]=Kui tegu on OTR-sõnumiga, seda ei näidata.
Comment[eu]=Mezu bat OTR mezu bat bada, ez da erakutsiko
Comment[fi]=Jos viesti on OTR-viesti, sitä ei näytetä
Comment[fr]=Si un message est un message OTR, il ne sera pas affiché
Comment[gl]=Se unha mensaxe é «OTR», non se mostrará.
Comment[hu]=Ha az üzenet egy OTR üzenet, nem lesz megjelenítve
Comment[ia]=Si un message es un message OTR, non essara monstrate
Comment[it]=Se un messaggio è un messaggio OTR, non sarà mostrato
Comment[ka]=თუ შეტყობინება OTR შეტყობინებაა, ის არ ნაჩვენები არ იქნება
Comment[ko]=OTR 메시지이면 표시되지 않습니다
Comment[nb]=Hvis en melding er en OTR-melding blir den ikke vist
Comment[nl]=Als een bericht een OTR-bericht is, zal het niet getoond worden
Comment[nn]=Viss ei melding er ei OTR-melding, vert ho ikkje vist
Comment[pl]=Jeśli wiadomość jest wiadomością OTR, to nie zostanie pokazana
Comment[pt]=Se uma dada mensagem for em OTR, não será apresentada
Comment[pt_BR]=Se receber uma mensagem em OTR, ela não será apresentada
Comment[ru]=Если сообщение зашифровано по протоколу OTR, то оно не будет показано
Comment[sk]=Ak správa je OTR správa, nebude zobrazená
Comment[sl]=Če je sporočilo vrste OTR, ne bo prikazano
Comment[sr]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavian]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavianlatin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sr@latin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sv]=Om ett meddelande är ett OTR-meddelande, kommer det inte att visas
Comment[tr]=Bir ileti kayıt dışı ise gösterilmeyecektir
Comment[uk]=Якщо повідомлення є повідомленням OTR, його не буде показано
Comment[x-test]=xxIf a message is an OTR message, it will not be shownxx
Comment[zh_CN]=如果消息是非公开消息，该消息将不会显示
Comment[zh_TW]=如果是私下加密（Off The Record）的訊息，則不會顯示
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_otr
X-KDE-PluginInfo-Author=Marcin Ziemiński
X-KDE-PluginInfo-Email=zieminn@gmail.com
X-KDE-PluginInfo-Name=otr
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui_23.04.3.orig.tar.xz: ktp-text-ui-23.04.3/filters/otr/ktptextui_message_filter_otr.desktop.cmake <==
[Desktop Entry]
Name=OTR
Name[bs]=OTR
Name[ca]=OTR
Name[ca@valencia]=OTR
Name[cs]=OTR
Name[da]=OTR
Name[de]=OTR
Name[el]=OTR
Name[en_GB]=OTR
Name[es]=OTR
Name[et]=OTR
Name[eu]=OTR
Name[fi]=OTR
Name[fr]=OTR
Name[gl]=OTR
Name[hu]=OTR
Name[ia]=OTR
Name[it]=OTR
Name[ka]=OTR
Name[ko]=OTR
Name[nb]=OTR
Name[nl]=OTR
Name[nn]=OTR
Name[pl]=OTR
Name[pt]=OTR
Name[pt_BR]=OTR
Name[ro]=OTR
Name[ru]=OTR
Name[sk]=OTR
Name[sl]=OTR
Name[sr]=ОТР
Name[sr@ijekavian]=ОТР
Name[sr@ijekavianlatin]=OTR
Name[sr@latin]=OTR
Name[sv]=OTR
Name[tr]=OTR
Name[uk]=OTR
Name[x-test]=xxOTRxx
Name[zh_CN]=非公开加密
Name[zh_TW]=OTR
Comment=If a message is an OTR message, it will not be shown
Comment[bs]=Ako je poruka OTR poruka, ona neće biti prikazana
Comment[ca]=Si un missatge és OTR, no es mostrarà
Comment[ca@valencia]=Si un missatge és OTR, no es mostrarà
Comment[cs]=Pokud je zpráva OTR, nebude zobrazena
Comment[da]=Hvis en besked er en OTR-besked, vil den ikke blive vist
Comment[de]=Wenn eine Nachricht vom Typ OTR ist, wird sie nicht angezeigt
Comment[el]=Αν ένα μήνυμα είναι μήνυμα OTR, δεν θα εμφανιστεί
Comment[en_GB]=If a message is an OTR message, it will not be shown
Comment[es]=Si un mensaje es un mensaje OTR, no se mostrará
Comment[et]=Kui tegu on OTR-sõnumiga, seda ei näidata.
Comment[eu]=Mezu bat OTR mezu bat bada, ez da erakutsiko
Comment[fi]=Jos viesti on OTR-viesti, sitä ei näytetä
Comment[fr]=Si un message est un message OTR, il ne sera pas affiché
Comment[gl]=Se unha mensaxe é «OTR», non se amosará.
Comment[hu]=Ha az üzenet egy OTR üzenet, nem lesz megjelenítve
Comment[ia]=Si un message es un message OTR, non essara monstrate
Comment[it]=Se un messaggio è un messaggio OTR, non sarà mostrato
Comment[ka]=თუ შეტყობინება OTR შეტყობინებაა, ის არ ნაჩვენები არ იქნება
Comment[ko]=OTR 메시지이면 표시되지 않습니다
Comment[nb]=Hvis en melding er en OTR-melding blir den ikke vist
Comment[nl]=Als een bericht een OTR-bericht is, zal het niet getoond worden
Comment[nn]=Viss ei melding er ei OTR-melding, vert ho ikkje vist
Comment[pl]=Jeśli wiadomość jest wiadomością OTR, to nie zostanie pokazana
Comment[pt]=Se uma dada mensagem for em OTR, não será apresentada
Comment[pt_BR]=Se receber uma mensagem em OTR, ela não será apresentada
Comment[ru]=Если сообщение зашифровано по протоколу OTR, то оно не будет показано
Comment[sk]=Ak správa je OTR správa, nebude zobrazená
Comment[sl]=Če je sporočilo vrste OTR, ne bo prikazano
Comment[sr]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavian]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavianlatin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sr@latin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sv]=Om ett meddelande är ett OTR-meddelande, kommer det inte att visas
Comment[tr]=Bir ileti kayıt dışı ise gösterilmeyecektir
Comment[uk]=Якщо повідомлення є повідомленням OTR, його не буде показано
Comment[x-test]=xxIf a message is an OTR message, it will not be shownxx
Comment[zh_CN]=如果消息是非公开消息，该消息将不会显示
Comment[zh_TW]=如果是私下加密（Off The Record）的訊息，則不會顯示
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_otr
X-KDE-PluginInfo-Author=Marcin Ziemiński
X-KDE-PluginInfo-Email=zieminn@gmail.com
X-KDE-PluginInfo-Name=otr
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
